# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d min resterende leestijd ",
    "Also available in:": "Ook beschikbaar in:",
    "Archive": "Archief",
    "Categories": "Categorieën",
    "Comments": "Commentaar",
    "LANGUAGE": "Nederlands",
    "Languages:": "Talen:",
    "More posts about %s": "Meer berichten over %s",
    "Newer posts": "Nieuwere berichten",
    "Next post": "Volgend bericht",
    "No posts found.": "Geen berichten gevonden.",
    "Nothing found.": "Niets gevonden.",
    "Older posts": "Oudere berichten",
    "Original site": "Originele site",
    "Posted:": "Geplaatst:",
    "Posts about %s": "Berichten over %s",
    "Posts for year %s": "Berichten voor het jaar %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Berichten voor {month} {year}",
    "Previous post": "Vorig bericht",
    "Publication date": "Publicatiedatum",
    "RSS feed": "RSS-feed",
    "Read in English": "Lees in het Nederlands",
    "Read more": "Lees verder",
    "Skip to main content": "Ga door naar de hoofdinhoud",
    "Source": "Bron",
    "Tags and Categories": "Tags en Categorieën",
    "Tags": "Tags",
    "old posts, page %d": "oude berichten, pagina %d",
    "page %d": "pagina %d",
}
