/*
	jQuery Colorbox language configuration
	language: Hungarian (hu)
	translated by: kovadani
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "{current}/{total} kép",
	previous: "Előző",
	next: "Következő",
	close: "Bezár",
	xhrError: "A tartalmat nem sikerült betölteni.",
	imgError: "A képet nem sikerült betölteni.",
	slideshowStart: "Diavetítés indítása",
	slideshowStop: "Diavetítés leállítása"
});