# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d dakikalık okuma",
    "Also available in:": "Şu dilde de mevcut:",
    "Archive": "Arşiv",
    "Categories": "Kategoriler",
    "Comments": "Yorumlar",
    "LANGUAGE": "Türkçe",
    "Languages:": "Diller:",
    "More posts about %s": "%s ilgili diğer yazılar",
    "Newer posts": "Daha yeni yazılar",
    "Next post": "Sonraki yazı",
    "No posts found.": "Yazı bulunamadı.",
    "Nothing found.": "Hiçbir şey bulunamadı.",
    "Older posts": "Daha eski yazılar",
    "Original site": "Orjinal web sayfası",
    "Posted:": "Yayın tarihi:",
    "Posts about %s": "%s ile ilgili yazılar",
    "Posts for year %s": "%s yılındaki yazılar",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "{month} {year} göre yazılar",
    "Previous post": "Önceki yazı",
    "Publication date": "Yayınlanma tarihi",
    "RSS feed": "RSS kaynağı",
    "Read in English": "Türkçe olarak oku",
    "Read more": "Devamını oku",
    "Skip to main content": "Ana içeriğe geç",
    "Source": "Kaynak",
    "Tags and Categories": "Etiketler ve Kategoriler",
    "Tags": "Etiketler",
    "old posts, page %d": "eski yazılar, sayfa %d",
    "page %d": "sayfa %d",
}
