# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "Also available in:": "उपलब्ध भाषाएँ:",
    "Archive": "आर्काइव",
    "Categories": "श्रेणियाँ",
    "Comments": "",
    "LANGUAGE": "हिन्दी",
    "Languages:": "",
    "More posts about %s": "%s के बारे में अौर पोस्टें",
    "Newer posts": "नई पोस्टें",
    "Next post": "अगली पोस्ट",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "पुरानी पोस्टें",
    "Original site": "असली साइट",
    "Posted:": "पोस्टेड:",
    "Posts about %s": "%s के बारे में पोस्टें",
    "Posts for year %s": "साल %s की पोस्टें",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "{month} {year} की पोस्टें",
    "Previous post": "पिछली पोस्ट",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "हिन्दी में पढ़िए",
    "Read more": "और पढ़िए",
    "Skip to main content": "",
    "Source": "सोर्स",
    "Tags and Categories": "टैग्स और श्रेणियाँ",
    "Tags": "टैग्स",
    "old posts, page %d": "पुरानी पोस्टें, पृष्‍ठ %d",
    "page %d": "पृष्‍ठ %d",
}
