/*
	jQuery Colorbox language configuration
	language: Dutch (nl)
	translated by: barryvdh
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Afbeelding {current} van {total}",
	previous: "Vorige",
	next: "Volgende",
	close: "Sluiten",
	xhrError: "Deze inhoud kan niet geladen worden.",
	imgError: "Deze afbeelding kan niet geladen worden.",
	slideshowStart: "Diashow starten",
	slideshowStop: "Diashow stoppen"
});