# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "읽기 %d분 남음.",
    "Also available in:": "",
    "Archive": "저장소",
    "Categories": "분류",
    "Comments": "댓글",
    "LANGUAGE": "영어",
    "Languages:": "언어:",
    "More posts about %s": "%s에 대한 또다른 포스트",
    "Newer posts": "최신 포스트",
    "Next post": "다음 포스트",
    "No posts found.": "검색된 포스트 없음.",
    "Nothing found.": "검색 결과 없음.",
    "Older posts": "옛날 포스트",
    "Original site": "출처",
    "Posted:": "",
    "Posts about %s": "%s에 대한 포스트",
    "Posts for year %s": "%s년도 포스트",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "{year}년 {month}월에 쓴 포스트",
    "Previous post": "이전 포스트",
    "Publication date": "발간일",
    "RSS feed": "RSS 목록",
    "Read in English": "영어로 읽기",
    "Read more": "더 읽기",
    "Skip to main content": "주 콘텐츠로 바로가기",
    "Source": "원문",
    "Tags and Categories": "태그와 분류",
    "Tags": "태그",
    "old posts, page %d": "이전 포스트, 페이지 %d",
    "page %d": "페이지 %d",
}
