# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "Also available in:": "Eskuragarria hemen ere:",
    "Archive": "Artxiboa",
    "Categories": "Kategoriak",
    "Comments": "",
    "LANGUAGE": "Euskara",
    "Languages:": "",
    "More posts about %s": "%s-ri buruzko post gehiago",
    "Newer posts": "Post berrienak",
    "Next post": "Hurrengo posta",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "Post zaharrenak",
    "Original site": "Jatorrizko orria",
    "Posted:": "Argitaratuta:",
    "Posts about %s": "%s-ri buruzko postak",
    "Posts for year %s": "%s. urteko postak",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "{year}ko {month}ren postak",
    "Previous post": "Aurreko posta",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "Euskaraz irakurri",
    "Read more": "Irakurri gehiago",
    "Skip to main content": "",
    "Source": "Iturria",
    "Tags and Categories": "Etiketak eta Kategoriak",
    "Tags": "Etiketak",
    "old posts, page %d": "Post zaharren, orria %d",
    "page %d": "orria %d",
}
