# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d минута је преостало за читање",
    "Also available in:": "Такође доступан у:",
    "Archive": "Архива",
    "Categories": "Категорије",
    "Comments": "Коментари",
    "LANGUAGE": "Српски",
    "Languages:": "Језици:",
    "More posts about %s": "Више постова о %s",
    "Newer posts": "Новији постови",
    "Next post": "Следећи пост",
    "No posts found.": "Нема постова.",
    "Nothing found.": "Није ништа пронађено.",
    "Older posts": "Старији постови",
    "Original site": "Оригинал сајт",
    "Posted:": "Објављено:",
    "Posts about %s": "Постови о %s",
    "Posts for year %s": "Постови за годину %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Постови за {month} {year}",
    "Previous post": "Претходни пост",
    "Publication date": "Датум објаве",
    "RSS feed": "RSS feed",
    "Read in English": "Прочитај на српском",
    "Read more": "Прочитај више",
    "Skip to main content": "Прескочи на главни садржај",
    "Source": "Извор",
    "Tags and Categories": "Тагови и категорије",
    "Tags": "Тагови",
    "old posts, page %d": "стари постови, страна %d",
    "page %d": "страна %d",
}
