/*
	jQuery Colorbox language configuration
	language: Catala (ca)
	translated by: eduard salla
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Imatge {current} de {total}",
	previous: "Anterior",
	next: "Següent",
	close: "Tancar",
	xhrError: "Error en la càrrega del contingut.",
	imgError: "Error en la càrrega de la imatge."
});
