/*
  jQuery Colorbox language configuration
	language: Spanish (es)
	translated by: migolo
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Imagen {current} de {total}",
	previous: "Anterior",
	next: "Siguiente",
	close: "Cerrar",
	xhrError: "Error en la carga del contenido.",
	imgError: "Error en la carga de la imagen."
});
