/*
	jQuery Colorbox language configuration
	language: Myanmar (my)
	translated by: Yan Naing
*/
jQuery.extend(jQuery.colorbox.settings, {
  current: "ပုံ {total} မှာ {current} မြောက်ပုံ",
	previous: "ရှေ့သို့",
	next: "နောက်သို့",
	close: "ပိတ်မည်",
	xhrError: "ပါဝင်သော အကြောင်းအရာများ ဖော်ပြရာတွင် အနည်းငယ် ချို့ယွင်းမှုရှိနေပါသည်",
	imgError: "ပုံပြသရာတွင် အနည်းငယ် ချို့ယွင်းချက် ရှိနေပါသည်",
	slideshowStart: "ပုံများ စတင်ပြသမည်",
	slideshowStop: "ပုံပြသခြင်း ရပ်ဆိုင်မည်"
});
