# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d menit tersisa untuk membaca",
    "Also available in:": "Juga tersedia dalam:",
    "Archive": "Arsip",
    "Categories": "Kategori",
    "Comments": "Komentar",
    "LANGUAGE": "Inggris",
    "Languages:": "Bahasa:",
    "More posts about %s": "Lebih banyak tulisan tentang %s",
    "Newer posts": "Tulisan lebih baru",
    "Next post": "Tulisan berikutnya",
    "No posts found.": "Tidak ada tulisan yang ditemukan.",
    "Nothing found.": "Tidak ditemukan.",
    "Older posts": "Tulisan lebih lama",
    "Original site": "Situs orisinal",
    "Posted:": "Ditulis oleh:",
    "Posts about %s": "Tulisan tentang %s",
    "Posts for year %s": "Tulisan untuk tahun %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Tulisan untuk {month} {year}",
    "Previous post": "Tulisan sebelumnya",
    "Publication date": "Tanggal publikasi",
    "RSS feed": "Sindikasi RSS",
    "Read in English": "Baca dalam bahasa Inggris",
    "Read more": "Baca selengkapnya",
    "Skip to main content": "Lanjutkan ke konten utama",
    "Source": "Sumber",
    "Tags and Categories": "Tag dan Kategori",
    "Tags": "Tag",
    "old posts, page %d": "tulisan lama, halaman %d",
    "page %d": "halaman %d",
}
