/*
jQuery Colorbox language configuration
language: Bengali (bn)
translated by: Arkaprava Majumder
http://github.com/arkaindas
*/
jQuery.extend(jQuery.colorbox.settings, {
current: "ছবি {current} এর {total}",
previous: "আগে",
next: "পরে",
close: "বন্ধ",
xhrError: "এই কন্টেন্ট লোড করা যায়নি.",
imgError: "এই ছবিটি লোড করা যায়নি.",
slideshowStart: "স্লাইডশো শুরু",
slideshowStop: "স্লাইডশো বন্ধ"
});
