# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "Il reste encore %d min. de lecture",
    "Also available in:": "Egalement disponible en:",
    "Archive": "Archives",
    "Categories": "Catégories",
    "Comments": "Commentaires",
    "LANGUAGE": "Français",
    "Languages:": "Langues:",
    "More posts about %s": "Plus d'articles sur %s",
    "Newer posts": "Billets récents",
    "Next post": "Article suivant",
    "No posts found.": "Pas de billets.",
    "Nothing found.": "Pas de résultats.",
    "Older posts": "Anciens articles",
    "Original site": "Site d'origine",
    "Posted:": "Publié:",
    "Posts about %s": "Articles sur %s",
    "Posts for year %s": "Articles de l'année %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Articles de {month} {year}",
    "Previous post": "Article précédent",
    "Publication date": "Date de publication",
    "RSS feed": "Flux RSS",
    "Read in English": "Lire en français",
    "Read more": "Lire la suite",
    "Skip to main content": "Aller au contenu principal",
    "Source": "Source",
    "Tags and Categories": "Étiquettes et catégories",
    "Tags": "Étiquettes",
    "old posts, page %d": "anciens articles, page %d",
    "page %d": "page %d",
}
