/*
	jQuery Colorbox language configuration
	language: Turkish (tr)
	translated by: Caner ÖNCEL
	site: egonomik.com
	
	edited by: Sinan Eldem
	www.sinaneldem.com.tr
*/
jQuery.extend(jQuery.colorbox.settings, {
  current: "Görsel {current} / {total}",
  previous: "Önceki",
  next: "Sonraki",
  close: "Kapat",
  xhrError: "İçerik yüklenirken hata meydana geldi.",
  imgError: "Resim yüklenirken hata meydana geldi.",
  slideshowStart: "Slaytı Başlat",
  slideshowStop: "Slaytı Durdur"
});
