/*
	jQuery Colorbox language configuration
	language: Persian (Farsi)
	translated by: Mahdi Jaberzadeh Ansari (MJZSoft)
	site: www.mjzsoft.ir
	email: mahdijaberzadehansari (at) yahoo.co.uk
	Please note : Persian language is right to left like arabic.
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "تصویر {current} از {total}",
	previous: "قبلی",
	next: "بعدی",
	close: "بستن",
	xhrError: "متاسفانه محتویات مورد نظر قابل نمایش نیست.",
	imgError: "متاسفانه بارگذاری این عکس با مشکل مواجه شده است.",
	slideshowStart: "آغاز نمایش خودکار",
	slideshowStop: "توقف نمایش خودکار"
});
