/*
	jQuery Colorbox language configuration
	language: Greek (gr)
	translated by: S.Demirtzoglou
	site: webiq.gr
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Εικόνα {current} από {total}",
	previous: "Προηγούμενη",
	next: "Επόμενη",
	close: "Απόκρυψη",
	xhrError: "Το περιεχόμενο δεν μπόρεσε να φορτωθεί.",
	imgError: "Απέτυχε η φόρτωση της εικόνας.",
	slideshowStart: "Έναρξη παρουσίασης",
	slideshowStop: "Παύση παρουσίασης"
});
