/*
	jQuery Colorbox language configuration
	language: Hebrew (he)
	translated by: DavidCo
	site: DavidCo.me
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "תמונה {current} מתוך {total}",
	previous: "הקודם",
	next: "הבא",
	close: "סגור",
	xhrError: "שגיאה בטעינת התוכן.",
	imgError: "שגיאה בטעינת התמונה.",
	slideshowStart: "התחל מצגת",
	slideshowStop: "עצור מצגת"
});
