/*
  jQuery Colorbox language configuration
  language: French (fr)
  translated by: oaubert
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "image {current} sur {total}",
	previous: "pr&eacute;c&eacute;dente",
	next: "suivante",
	close: "fermer",
	xhrError: "Impossible de charger ce contenu.",
	imgError: "Impossible de charger cette image.",
	slideshowStart: "d&eacute;marrer la pr&eacute;sentation",
	slideshowStop: "arr&ecirc;ter la pr&eacute;sentation"
});
