/*
	jQuery Colorbox language configuration
	language: Chinese Traditional (zh-TW)
	translated by: Atans Chiu
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "圖片 {current} 總共 {total}",
	previous: "上一頁",
	next: "下一頁",
	close: "關閉",
	xhrError: "此內容加載失敗.",
	imgError: "此圖片加載失敗.",
	slideshowStart: "開始幻燈片",
	slideshowStop: "結束幻燈片"
});