/*
	jQuery Colorbox language configuration
	language: Lithuanian (lt)
	translated by: Tomas Norkūnas
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Nuotrauka {current} iš {total}",
	previous: "Atgal",
	next: "Pirmyn",
	close: "Uždaryti",
	xhrError: "Nepavyko užkrauti turinio.",
	imgError: "Nepavyko užkrauti nuotraukos.",
	slideshowStart: "Pradėti automatinę peržiūrą",
	slideshowStop: "Sustabdyti automatinę peržiūrą"
});